/*
	Automatically generated source file template for a task.
	(c) European Space Agency


	Title: dsinfo
	Package: daltools
	Author: Mark Thomas
	Affiliation: CARA/ESA
	Email: mthomas@astro.estec.esa.nl
	Purpose: Retrieve information from object
	Description: Retrieve information from object


*/

#include <Tracer.h>
#include <errstr.h>
#include <param.h>
#include <Dal.h>
#include <CompoundName.h>


#include "dsinfo.h"


static void
dumpHistory( const Attributable* attributable, ostream& os )
{
	PROC
	const unsigned int	historys( attributable -> historys() );
	os << "Attributable: " << attributable -> qualifiedName() << endl;
	for( unsigned int i = 0; i < historys; ++i )
	{
		os << attributable -> history( i ) << endl;
	} // for
	ENDPROC
}


static void
dumpComment( const Attributable* attributable, ostream& os )
{
	PROC
	const unsigned int	comments( attributable -> comments() );
	os << "Attributable: " << attributable -> qualifiedName() << endl;
	for( unsigned int i = 0; i < comments; ++i )
	{
		os << attributable -> comment( i ) << endl;
	} // for
	ENDPROC
}


static void
dumpProcess( const DataSet* set, ostream& os )
{
	PROC
	const unsigned int	processes( dataSetServer -> processes( set ));
	os << "DataSet: " << set -> name() << endl;
	for( unsigned int i = 0; i < processes; ++i )
	{
		os << dataSetServer -> process( set, i ) << endl;
	} // for
	ENDPROC
}


void dsinfo()
{
	PROC
	ostream&		os = cout;
	vector<string>		objectNames = stringListParameter( "objects" );
	const string		category = stringParameter( "category" );

	for( unsigned int i = 0; i < objectNames.size(); ++i )
	{
		const string		object( objectNames[ i ] );
		const CompoundName	ocn( object, CompoundName::Any, 0, Dal::Read, DataSetServer::HighLow );

		switch( ocn.state() )
		{
			case CompoundName::DataSetName :

				if( category == "process" )
				{
					dumpProcess( ocn.dataSet(), os );
				}
				else if( category == "history" )
				{
					dumpHistory( ocn.attributable(), os );
				}
				else if( category == "comment" )
				{
					dumpComment( ocn.attributable(), os );
				}
				else
				{
					cerr << "Unrecognised category type: '" << category << "'" << Sas::error( "unrecognisedCategory" );
				} // if
				break;
			case CompoundName::BlockName :
				if( category == "history" )
				{
					dumpHistory( ocn.attributable(), os );
				}
				else if( category == "comment" )
				{
					dumpComment( ocn.attributable(), os );
				}
				else
				{
					cerr << "Unrecognised category type: '" << category << "'" << Sas::error( "unrecognisedCategory" );
				} // if
				break;
			default :
				errstr << "Unrecognised object type '" << object << "'" << Sas::error( "unrecognisedObject" );
		} // switch
	} // for
	ENDPROC
}
