/*
	Automatically generated source file template for a task.
	(c) European Space Agency


	Title: dslatts
	Package: daltools
	Author: Mark Thomas
	Affiliation: CARA/ESA
	Email: mthomas@astro.estec.esa.nl
	Purpose: List the attributes in the given attributable objects
	Description: List the attributes in the given attributable objects


*/

#include <Tracer.h>
#include <param.h>
#include <Dal.h>
#include <dal_utilities.h>
#include <CompoundName.h>


#include "dslatts.h"

static void
listAttributes( const Attributable* attributable, ostream& os )
{
	PROC

	os << "ATTRIBUTABLE: " << attributable -> qualifiedName() << endl;
	os << "NAME    ";
	os << "TYPE    ";
	os << "VALUE   ";
	os << "LABEL   ";
	os << "UNITS   ";
	os << endl;

	const unsigned int	attributes( attributable -> attributes() );

	for( unsigned int i = 0; i < attributes; ++i )
	{
		const Attribute*	attribute( attributable -> attribute( i ) );
		os << attribute -> name() << "   ";
		os << toString( attribute -> dataType() ) << "   ";
		os << attribute -> asString() << "   ";
		os << attribute -> label() << "   ";
		os << attribute -> units() << "   ";
		os << endl;
	} // for
	ENDPROC
}



void dslatts()
{
	PROC
	const vector<string>	objects( stringListParameter( "objects" ) );
	ostream&		os( cout );

	for( unsigned int i = 0; i < objects.size(); ++i )
	{
		const string		name( objects[ i ] );
		DataSet*		set( dataSetServer -> open( name, Dal::Read, DataSetServer::Low ) );
		const CompoundName	cn( name, CompoundName::AnyAttributableName, set );
		Attributable*		attributable( cn.attributable() );

		listAttributes( attributable, os );

		dataSetServer -> close( set );
	} // for
	ENDPROC
}


